from conan import ConanFile
from conan.tools.cmake import CMakeToolchain,cmake_layout
from conan.tools.files import copy
import os

required_conan_version = ">=2.0.0"

class AST(ConanFile):
    name = "AST"
    version = "1.0.0"
    description = """Old school project
                    Turn based strategy game"""
    license = "MIT"
    author = "JackCarterSmith (j@jcsmith.fr)"
    url = "https://git.jcsmith.fr/JCS-Prod/AST"
    
    package_type = "application"
    revision_mode = "scm"
    settings = "os", "compiler", "build_type", "arch"
    generators = "CMakeDeps"
    
#    default_options = {
#        "shared": True
#    }
    
    def configure(self):
        self.options["sdl"].vulkan = False
        self.options["sdl"].opengles = False
        self.options["sdl"].iconv = False
        self.options["sdl_image"].with_libjpeg = False
        self.options["sdl_image"].with_libtiff = False
        self.options["sdl_image"].with_libwebp = False
        self.options["sdl_image"].lbm = False
        self.options["sdl_image"].pcx = False
        self.options["sdl_image"].pnm = False
        self.options["sdl_image"].svg = False
        self.options["sdl_image"].tga = False
        self.options["sdl_image"].xcf = False
        self.options["sdl_image"].xpm = False
        self.options["sdl_image"].xv = False
        
        if self.settings.os == "Linux":
            self.options["sdl"].shared = False
            self.options["sdl"].wayland = False
            self.options["sdl"].nas = True
            self.options["sdl_image"].shared = False
            
        if self.settings.os == "Windows":
            self.options["sdl"].shared = True
            self.options["sdl"].directx = False
            self.options["sdl_image"].shared = True
    
    def requirements(self):
        self.requires("sdl/2.30.9", force=True)
        self.requires("sdl_image/[~2.8]")
        
    def layout(self):
        self.folders.build_folder_vars = ["settings.os", "settings.compiler", "settings.build_type"]
        cmake_layout(self)
        
    def generate(self):
#        cmake = CMakeDeps(self)
#        if self.options["AST"].shared:
#            cmake.configuration = "ReleaseShared"
#        cmake.generate()
        tc = CMakeToolchain(self)
        #tc.user_presets_path = False
        tc.generate()
        for dep in self.dependencies.values():
            if len(dep.cpp_info.bindirs) > 0:
                if self.settings.os == "Windows":
                    copy(self, "*.dll", dep.cpp_info.bindirs[0], os.path.join(self.build_folder, "bin"))
                else:
                    copy(self, "*.so", dep.cpp_info.bindirs[0], os.path.join(self.build_folder, "bin"))

#    def package(self):
#        copy(self, "LICENSE", src=self.source_folder, dst=os.path.join(self.package_folder, "licenses"))
#        copy(self, pattern="*.h", src=os.path.join(self.source_folder, "include"), dst=os.path.join(self.package_folder, "include"))
#        copy(self, pattern="*.a", src=self.build_folder, dst=os.path.join(self.package_folder, "lib"), keep_path=False)
#        copy(self, pattern="*.so", src=self.build_folder, dst=os.path.join(self.package_folder, "lib"), keep_path=False)
#        copy(self, pattern="*.lib", src=self.build_folder, dst=os.path.join(self.package_folder, "lib"), keep_path=False)
#        copy(self, pattern="*.dll", src=self.build_folder, dst=os.path.join(self.package_folder, "bin"), keep_path=False)
